package it.arnaldo.unibs.tamagolem;

/**
 * Rappresenta un collegamento (arco) tra due elementi nel grafo delle interazioni.
 * Ogni collegamento ha un valore numerico che indica la forza (positiva o negativa) dell'interazione.
 */
public class ElementLink {

    /** Valore dell'interazione tra elementi */
    private final int value;

    /** L'elemento verso cui punta il collegamento */
    private final Element element;

    /**
     * Costruttore della classe ElementLink.
     *
     * @param value Il valore dell'interazione
     * @param element L'elemento collegato
     */
    public ElementLink(int value, Element element) {
        this.value = value;
        this.element = element;
    }

    /**
     * Restituisce il valore dell'interazione.
     *
     * @return Il valore numerico dell'interazione
     */
    public int getValue() {
        return value;
    }

    /**
     * Restituisce l'elemento collegato.
     *
     * @return L'elemento di destinazione del collegamento
     */
    public Element getElement() {
        return element;
    }

    /**
     * Restituisce la forza dell'interazione solo se positiva.
     * Le interazioni negative non vengono conteggiate nel calcolo della forza totale.
     *
     * @return Il valore dell'interazione se positivo, altrimenti 0
     */
    public int getTotalStrength() {
        return value >= 0 ? value : 0;
    }
}
