package it.arnaldo.unibs.tamagolem;

import it.kibo.fp.lib.InputData;
import it.kibo.fp.lib.Menu;
import it.kibo.fp.lib.PrettyStrings;

/**
 * Classe che gestisce il ciclo principale del gioco e l'interazione iniziale con i giocatori.
 * Si occupa della creazione di una nuova partita e dell'avvio del gioco.
 */
public class GameLoop {

    /** Riferimento all'istanza corrente del gioco */
    private Game game;

    /**
     * Avvia il menù iniziale e gestisce l'avvio di nuove partite.
     * Permette ai giocatori di creare una nuova partita e selezionare la difficoltà.
     */
    public void start() {
        String[] firstMenuEntries = {"New game"};
        Menu firstMenu = new Menu("TamaGolem", firstMenuEntries, true, true, false);
        int firstmenuChoise;

        do {
            boolean playGame = createNewGame();
            if (playGame) {
                game.start();
            }
            firstmenuChoise = firstMenu.choose();
         } while (firstmenuChoise == 1);
    }

    /**
     * Crea una nuova partita chiedendo i nomi dei due giocatori e la modalità di difficoltà.
     *
     * @return true se la partita è stata creata con successo, false altrimenti
     */
    public boolean createNewGame() {
        String[] diffucultyMenuEntries = {"Easy", "Medium", "Hard"};
        Menu difficultyMenu = new Menu("Select Mode", diffucultyMenuEntries, true, true, false);

        Player p1 = new Player(InputData.readString(PrettyStrings.frame("""
                    Player 1:
                    \tChoose your name\s""", 30, false, false), true));

        Player p2 = new Player(InputData.readString(PrettyStrings.frame("""
                Player 2:
                \tChoose your name\s""", 30, false, false), true));

        int difficultyChoise = difficultyMenu.choose();
        Modes difficulty = null;

        switch (difficultyChoise){
            case 1 ->  difficulty = Modes.EASY;
            case 2 -> difficulty = Modes.MEDIUM;
            case 3 -> difficulty = Modes.HARD;
        }

        if (difficulty != null){
            game = new Game(p1, p2, WorldBuilder.buildWorld(difficulty));
            return true;
        }
        return false;
    }
}
