package it.arnaldo.unibs.tamagolem;

/**
 * Rappresenta una coppia di elementi (ad esempio per descrivere un'interazione tra due elementi).
 * È una classe semplice contenente due riferimenti a oggetti di tipo {@link Element}.
 */
public class Pair {

    /** Primo elemento della coppia */
    private final Element first;

    /** Secondo elemento della coppia */
    private final Element second;

    /**
     * Costruttore della classe Pair.
     *
     * @param first Il primo elemento della coppia
     * @param second Il secondo elemento della coppia
     */
    Pair(Element first, Element second) {
        this.first = first;
        this.second = second;
    }

    /**
     * Restituisce il primo elemento della coppia.
     *
     * @return Il primo elemento
     */
    public Element getFirst() {
        return first;
    }

    /**
     * Restituisce il secondo elemento della coppia.
     *
     * @return Il secondo elemento
     */
    public Element getSecond() {
        return second;
    }

    /**
     * Restituisce una rappresentazione testuale della coppia di elementi.
     *
     * @return Una stringa nel formato "(elemento1, elemento2)"
     */
    @Override
    public String toString(){
        return "(" + first.toString() + ", " + second.toString() + ")";
    }
}