package it.arnaldo.unibs.tamagolem;

import java.util.ArrayList;

/**
 * Rappresenta un giocatore nel gioco TamaGolem.
 * Ogni giocatore ha un nome e una lista di TamaGolem a disposizione.
 */
public class Player {

    /** Nome del giocatore */
    private final String name;

    /** Lista dei TamaGolem appartenenti al giocatore */
    private final ArrayList<TamaGolem> tamaGolems;

    /**
     * Costruttore della classe Player.
     *
     * @param name Il nome del giocatore
     */
    public Player(String name) {
        this.name = name;
        this.tamaGolems = new ArrayList<>();
    }

    /**
     * Restituisce il nome del giocatore.
     *
     * @return Il nome del giocatore
     */
    public String getName() {
        return name;
    }

    /**
     * Restituisce la lista dei TamaGolem del giocatore.
     *
     * @return Una lista di TamaGolem
     */
    public ArrayList<TamaGolem> getTamaGolems() {
        return tamaGolems;
    }

    /**
     * Restituisce il prossimo TamaGolem disponibile (il primo nella lista).
     *
     * @return Il prossimo TamaGolem, oppure null se la lista è vuota
     */
    public TamaGolem getNextTamaGolem() {
        if (tamaGolems.isEmpty()) {
            return null;
        } else {
            return tamaGolems.get(0);
        }
    }

    /**
     * Aggiunge un TamaGolem alla lista del giocatore.
     *
     * @param t Il TamaGolem da aggiungere
     */
    public void addTamaGolem(TamaGolem t) {
        tamaGolems.add(t);
    }

    /**
     * Rimuove un TamaGolem dalla lista del giocatore.
     *
     * @param t Il TamaGolem da rimuovere
     */
    public void removeTamaGolem(TamaGolem t) {
        tamaGolems.remove(t);
    }

    /**
     * Verifica se il giocatore ha ancora almeno un TamaGolem vivo.
     *
     * @return true se ha ancora golem disponibili, false altrimenti
     */
    public boolean isAlive() {
        return !tamaGolems.isEmpty();
    }


}
